@@ -11,7 +11,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -21,109 +21,126 @@
 using System;
 using Gtk;
 using Gdk;
-using LongoMatch.Video.Handlers;
+using LongoMatch.Video.Common;
 
 
 namespace LongoMatch.Video.Player
-	      
+
 {
 	public interface IPlayer
 	{
-	
+
 
 		// Events
-		
-	
+
+
 		event         ErrorHandler Error;
 		event         System.EventHandler Eos;
-		event         LongoMatch.Video.Handlers.StateChangeHandler StateChange;
+		event         StateChangeHandler StateChange;
 		event         TickHandler Tick;
 		event         System.EventHandler GotDuration;
 		event         System.EventHandler SegmentDone;
 		event         System.EventHandler ReadyToSeek;
-		
-		
-		long StreamLength{
+
+
+		long StreamLength {
 			get;
 		}
-		
-		
-		
-		long CurrentTime{
+
+
+
+		long CurrentTime {
 			get;
-			
+
 		}
-		
-		double Position{
+
+		double Position {
 			get;
 			set;
-			
+
 		}
-		
+
 		bool LogoMode {
 			get;
 			set;
 		}
-		
-		double Volume{
+
+		bool DrawingMode {
+			set;
+		}
+
+		Pixbuf DrawingPixbuf {
+			set;
+		}
+
+		bool ExpandLogo {
 			get;
 			set;
-		}		
-		
+		}
+
+		double Volume {
+			get;
+			set;
+		}
+
 		bool Playing {
 			get;
 		}
-			
+
 		string Logo {
 			set;
 		}
-		
-		long AccurateCurrentTime{
+
+		Pixbuf LogoPixbuf {
+			set;
+		}
+
+		long AccurateCurrentTime {
 			get;
 		}
-		
+
 		bool SeekTime(long time,float rate, bool accurate);
-		
+
 		bool Play();
-		
+
 		bool Open(string mrl);
-		
+
 		bool SetRate(float rate);
-		
+
 		bool SetRateInSegment(float rate, long stopTime);
-		
-		
-		
+
+
+
 		void TogglePlay();
-		
+
 		void Pause();
-		
+
 		void Stop();
-				
+
 		void Close();
-		
-		
+
+
 		void Dispose();
-		
+
 		bool SegmentSeek(long start, long stop,float rate);
-		
+
 		bool SeekInSegment(long pos,float rate);
-		
+
 		bool NewFileSeek(long start, long stop,float rate);
-			
+
 		bool SegmentStartUpdate(long start,float rate);
-		
+
 		bool SegmentStopUpdate(long stop,float rate);
-		
+
 		bool SeekToNextFrame(float rate,bool in_segment);
-		
+
 		bool SeekToPreviousFrame(float rate,bool in_segment);
-		
+
 		Pixbuf GetCurrentFrame(int outwidth, int outheight);
-		
+
 		Pixbuf GetCurrentFrame();
-		
+
 		void CancelProgramedStop();
-		
+
 	}
 }
