@@ -19,6 +19,7 @@ using System;
 using System.IO;
 using System.Runtime.InteropServices;
 using Gtk;
+using LongoMatch.Video;
 using LongoMatch.Gui;
 
 namespace LongoMatch.Common
@@ -26,8 +27,6 @@ namespace LongoMatch.Common
 	public class GStreamer
 	{
 		
-		[DllImport("libgstreamer-0.10.dll") /* willfully unmapped */ ]
-		static extern void gst_init (int argc, string argv);
 		[DllImport("libgstreamer-0.10.dll") /* willfully unmapped */ ]
 		static extern IntPtr gst_registry_get_default ();
 		[DllImport("libgstreamer-0.10.dll") /* willfully unmapped */ ]
@@ -40,7 +39,7 @@ namespace LongoMatch.Common
 		
 		public static void Init() {
 			SetUpEnvironment ();
-			gst_init (0, "");
+			MultimediaFactory.InitBackend();
 		}
 		
 		public static bool CheckInstallation () {
