@@ -24,14 +24,16 @@ using Gdk;
 using LongoMatch.Video.Editor;
 using Mono.Unix;
 using System.IO;
+using LongoMatch.Common;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 using LongoMatch.Video.Player;
 using LongoMatch.Video;
 using LongoMatch.Video.Common;
 using LongoMatch.Gui;
 using LongoMatch.Gui.Dialog;
 using LongoMatch.Playlist;
+using LongoMatch.Services.JobsManager;
 
 
 
@@ -44,45 +46,46 @@ namespace LongoMatch.Gui.Component
 	{
 		public event PlayListNodeSelectedHandler PlayListNodeSelected;
 		public event ApplyCurrentRateHandler ApplyCurrentRate;
-		public event ProgressHandler Progress;
+		public event JobHandler NewRenderingJob;
 
 		private PlayerBin player;
-		private PlayListTimeNode plNode;
+		private PlayListPlay plNode;
 		private PlayList playList;
 		private uint timeout;
 		private object lock_node;
 		private bool clock_started = false;
-		private IVideoEditor videoEditor;
-		private MultimediaFactory factory;
 
-
-		public PlayListWidget ()
+		public PlayListWidget()
 		{
-			this.Build ();
-			lock_node = new System.Object ();
-			factory = new MultimediaFactory ();
+			this.Build();
+			lock_node = new System.Object();
 			playlisttreeview1.Reorderable = true;
 			playlisttreeview1.RowActivated += OnPlaylisttreeview1RowActivated;
 			playlisttreeview1.ApplyCurrentRate += OnApplyRate;
 			savebutton.Sensitive = false;
+
+			newbutton.CanFocus = false;
+			openbutton.CanFocus = false;
+			savebutton.CanFocus = false;
+			newvideobutton.CanFocus = false;
 		}
 
 		public void SetPlayer(PlayerBin player) {
 			this.player = player;
-			closebutton.Hide();
 			newvideobutton.Hide();
 		}
 
 		public void Load(string filePath) {
 			try {
-				playList = new PlayList(filePath);
+				playList = PlayList.Load(filePath);
 				Model = playList.GetModel();
 				label1.Visible = false;
 				newvideobutton.Show();
 				playlisttreeview1.PlayList = playList;
 				playlisttreeview1.Sensitive = true;
 				savebutton.Sensitive = true;
-			} catch {
+			} catch (Exception e){
+				Log.Exception (e);
 				MessagePopup.PopupMessage(this,MessageType.Error,Catalog.GetString("The file you are trying to load is not a playlist or it's not compatible with the current version"));
 			}
 		}
@@ -96,19 +99,19 @@ namespace LongoMatch.Gui.Component
 			}
 		}
 
-		public void Add(PlayListTimeNode plNode) {
-			if (playList!=null) {
+		public void Add(PlayListPlay plNode) {
+			if(playList!=null) {
 				Model.AppendValues(plNode);
 				playList.Add(plNode);
 			}
 		}
 
-		public PlayListTimeNode Next() {
-			if (playList.HasNext()) {
+		public PlayListPlay Next() {
+			if(playList.HasNext()) {
 				plNode = playList.Next();
 				playlisttreeview1.Selection.SelectPath(new TreePath(playList.GetCurrentIndex().ToString()));
 				playlisttreeview1.LoadedPlay = plNode;
-				if (PlayListNodeSelected != null && plNode.Valid) {
+				if(PlayListNodeSelected != null && plNode.Valid) {
 					PlayListNodeSelected(plNode,playList.HasNext());
 					StartClock();
 				}
@@ -123,12 +126,12 @@ namespace LongoMatch.Gui.Component
 
 		public void Prev() {
 			if ((player.AccurateCurrentTime - plNode.Start.MSeconds) < 500) {
-				//Seleccionando el elemento anterior si no han pasado más 500ms
+				//Seleccionando el elemento anterior si no han pasado mas 500ms
 				if (playList.HasPrev()) {
 					plNode = playList.Prev();
 					playlisttreeview1.Selection.SelectPath(new TreePath(playList.GetCurrentIndex().ToString()));
 					playlisttreeview1.LoadedPlay = plNode;
-					if (PlayListNodeSelected != null)
+					if(PlayListNodeSelected != null)
 						PlayListNodeSelected(plNode,playList.HasNext());
 					StartClock();
 				}
@@ -140,44 +143,39 @@ namespace LongoMatch.Gui.Component
 			}
 		}
 
-		public void StopEdition() {
-			if (videoEditor != null)
-				videoEditor.Cancel();
-		}
-
 		public void Stop() {
 			StopClock();
 		}
 
 		void StartClock()	{
-			if (player!=null && !clock_started) {
+			if(player!=null && !clock_started) {
 				timeout = GLib.Timeout.Add(20,CheckStopTime);
 				clock_started=true;
 			}
 		}
 
 		private void StopClock() {
-			if (clock_started) {
+			if(clock_started) {
 				GLib.Source.Remove(timeout);
 				clock_started = false;
 			}
 		}
 
 		private bool CheckStopTime() {
-			lock (lock_node) {
-				if (player != null) {
-					if (player.AccurateCurrentTime >= plNode.Stop.MSeconds-200) {
-						if (Next() == null)
+			lock(lock_node) {
+				if(player != null) {
+					if(player.AccurateCurrentTime >= plNode.Stop.MSeconds-200) {
+						if(Next() == null)
 							StopClock();
 					}
 				}
 				return true;
 			}
 		}
-		private PlayListTimeNode SelectPlayListNode(TreePath path) {
+		private PlayListPlay SelectPlayListNode(TreePath path) {
 
 			plNode = playList.Select(Int32.Parse(path.ToString()));
-			if (PlayListNodeSelected != null && plNode.Valid) {
+			if(PlayListNodeSelected != null && plNode.Valid) {
 				PlayListNodeSelected(plNode,playList.HasNext());
 				StartClock();
 			}
@@ -187,17 +185,12 @@ namespace LongoMatch.Gui.Component
 		private FileFilter FileFilter {
 			get {
 				FileFilter filter = new FileFilter();
-				filter.Name = "LGM playlist";
-				filter.AddPattern("*.lgm");
+				filter.Name = Catalog.GetString("LongoMatch playlist");
+				filter.AddPattern("*" + Constants.PLAYLIST_EXT);
 				return filter;
 			}
 		}
 
-		private void LoadEditor() {
-			videoEditor = factory.getVideoEditor();
-			videoEditor.Progress += new ProgressHandler(OnProgress);
-		}
-
 		protected virtual void OnPlaylisttreeview1RowActivated(object o, Gtk.RowActivatedArgs args)
 		{
 			playlisttreeview1.LoadedPlay = SelectPlayListNode(args.Path);
@@ -206,7 +199,7 @@ namespace LongoMatch.Gui.Component
 
 		protected virtual void OnSavebuttonClicked(object sender, System.EventArgs e)
 		{
-			if (playList != null) {
+			if(playList != null) {
 				playList.Save();
 			}
 		}
@@ -221,7 +214,7 @@ namespace LongoMatch.Gui.Component
 			fChooser.SetCurrentFolder(MainClass.PlayListDir());
 			fChooser.AddFilter(FileFilter);
 			fChooser.DoOverwriteConfirmation = true;
-			if (fChooser.Run() == (int)ResponseType.Accept)
+			if(fChooser.Run() == (int)ResponseType.Accept)
 				Load(fChooser.Filename);
 			fChooser.Destroy();
 		}
@@ -236,7 +229,7 @@ namespace LongoMatch.Gui.Component
 			fChooser.SetCurrentFolder(MainClass.PlayListDir());
 			fChooser.AddFilter(FileFilter);
 
-			if (fChooser.Run() == (int)ResponseType.Accept)
+			if(fChooser.Run() == (int)ResponseType.Accept)
 				Load(fChooser.Filename);
 			fChooser.Destroy();
 		}
@@ -248,76 +241,21 @@ namespace LongoMatch.Gui.Component
 
 		protected virtual void OnNewvideobuttonClicked(object sender, System.EventArgs e)
 		{
-			VideoEditionProperties vep;
-			int response;
+			Job job;
 
-			if (playList.Count == 0) {
+			if(playList.Count == 0) {
 				MessagePopup.PopupMessage(this,MessageType.Warning,
 				                          Catalog.GetString("The playlist is empty!"));
 				return;
 			}
 
-			vep = new VideoEditionProperties();
-			vep.TransientFor = (Gtk.Window)this.Toplevel;
-			response = vep.Run();
-			while (response == (int)ResponseType.Ok && vep.Filename == "") {
-				MessagePopup.PopupMessage(this, MessageType.Warning,
-				                          Catalog.GetString("Please, select a video file."));
-				response=vep.Run();
-			}
-			if (response ==(int)ResponseType.Ok) {
-				//FIXME:Create a new instance of the video editor until we fix the audio swith enable/disabled
-				LoadEditor();
-				//videoEditor.ClearList();
-				foreach (PlayListTimeNode segment in playList) {
-					if (segment.Valid)
-						videoEditor.AddSegment(segment.MediaFile.FilePath,
-						                       segment.Start.MSeconds,
-						                       segment.Duration.MSeconds,
-						                       segment.Rate,
-						                       segment.Name,
-						                       segment.MediaFile.HasAudio);
-				}
-				try {
-					videoEditor.VideoQuality = vep.VideoQuality;
-					videoEditor.AudioQuality = AudioQuality.Good;
-					videoEditor.VideoFormat = vep.VideoFormat;
-					videoEditor.AudioEncoder = vep.AudioEncoderType;
-					videoEditor.VideoEncoder = vep.VideoEncoderType;
-					videoEditor.OutputFile = vep.Filename;
-					videoEditor.EnableTitle = vep.TitleOverlay;
-					videoEditor.EnableAudio = vep.EnableAudio;
-					videoEditor.VideoMuxer = vep.VideoMuxer;
-					videoEditor.Start();
-					closebutton.Show();
-					newvideobutton.Hide();
-				}
-				catch (Exception ex) {
-					MessagePopup.PopupMessage(this, MessageType.Error, Catalog.GetString(ex.Message));
-				}
-			vep.Destroy();
-			}
+			job = GuiUtils.ConfigureRenderingJob(playList, this);
+			if (job != null && NewRenderingJob != null)
+					NewRenderingJob(job);
 		}
 
-		protected virtual void OnClosebuttonClicked(object sender, System.EventArgs e)
-		{
-			videoEditor.Cancel();
-			closebutton.Hide();
-			newvideobutton.Show();
-		}
-
-		protected virtual void OnProgress(float progress) {
-			if (Progress!= null)
-				Progress(progress);
-
-			if (progress ==1) {
-				closebutton.Hide();
-				newvideobutton.Show();
-			}
-		}
-
-		protected virtual void OnApplyRate(PlayListTimeNode plNode) {
-			if (ApplyCurrentRate != null)
+		protected virtual void OnApplyRate(PlayListPlay plNode) {
+			if(ApplyCurrentRate != null)
 				ApplyCurrentRate(plNode);
 		}
 	}
