@@ -2,6 +2,12 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
+#ifdef WIN32
+#define EXPORT __declspec (dllexport)
+#else
+#define EXPORT
+#endif
+
 #define TOTEM_OBJECT_HAS_SIGNAL(obj, name) (g_signal_lookup (name, g_type_from_name (G_OBJECT_TYPE_NAME (obj))) != 0)
 
 void totem_gdk_window_set_invisible_cursor (GdkWindow * window);
@@ -17,3 +23,5 @@ void totem_widget_set_preferred_size (GtkWidget * widget, gint width,
     gint height);
 gboolean totem_ratio_fits_screen (GdkWindow * window, int video_width,
     int video_height, gfloat ratio);
+
+EXPORT void init_backend (int argc, char **argv);
